@@ -16,6 +16,7 @@ from .sessions_requests import (
     SessionsUpdateRequest,
     SessionsSearchRequest,
     SessionsReplyRequest,
+    SessionScheduleRequest,
 )
 
 __all__ = [
@@ -26,6 +27,7 @@ __all__ = [
     "SessionsUpdateRequest",
     "SessionsSearchRequest",
     "SessionsReplyRequest",
+    "SessionScheduleRequest",
     # Messages
     "MessagesSendRequest",
     "MessagesCreateRequest",
