@@ -1,6 +1,6 @@
 from pydantic import BaseModel, Field
 from typing import Literal, Optional, Dict, Any
-from ..sessions import SessionStatus
+from ..sessions import SessionStatus, SessionUpdateFields
 from ..session_schedules import ScheduledMessageConfig, ScheduledNodeConfig
 from datetime import datetime
 from typing import Union
@@ -20,11 +20,12 @@ class SessionsFinishRequest(BaseModel):
     ending_survey_id: Optional[str] = Field(default=None, description="ID da pesquisa de satisfação para iniciar após o fechamento da sessão")
 
 class SessionsUpdateRequest(BaseModel):
-    metadata: Dict[str, Any] = Field(..., description="Metadados atualizados da sessão. Informações do seu CRM/sistema que retornam via webhook e podem ser usadas pelo agente de IA")
+    fields: SessionUpdateFields = Field(..., description="Campos a serem atualizados na sessão. Pode incluir metadata, status, agent_id, etc.")
 
 class SessionsSearchRequest(BaseModel):
     contact_id: Optional[str] = Field(default=None, description="ID do contato para buscar")
     status: Optional[SessionStatus] = Field(default=None, description="Status da sessão para buscar")
+    metadata: Optional[Dict[str, Union[str, int, float]]] = Field(default=None, description="Metadados da sessão para buscar")
     offset: Optional[int] = Field(default=None, description="Número de registros para pular")
     limit: Optional[int] = Field(default=100, description="Limite máximo de registros retornados")
 
